// Modules to control application life and create native browser window
const { app, BrowserWindow, Menu } = require('electron')
const path = require('path')

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let mainWindow

function createWindow() {
  // Create the browser window.
  mainWindow = new BrowserWindow({
    width: 800,
    height: 600,
    webPreferences: {
      preload: path.join(__dirname, 'preload.js')
    }
  })
  mainWindow.setTitle("Tennistavolo Novara Desktop");

  // and load the index.html of the app.
  mainWindow.loadFile('index.html')

  // Open the DevTools.
  // mainWindow.webContents.openDevTools()

  // Emitted when the window is closed.
  mainWindow.on('closed', function () {
    // Dereference the window object, usually you would store windows
    // in an array if your app supports multi windows, this is the time
    // when you should delete the corresponding element.
    mainWindow = null
  })
}

var menu = Menu.buildFromTemplate([
  {
    label: 'App',
    submenu: [
      {
        label: 'Info', click() {
          const { dialog } = require('electron');
          const options = {
            title: "Tennistavolo Novara Desktop",
            message: 'Tennistavolo Novara Desktop - Versione 1.1',
          };
          dialog.showMessageBox(null, options, (response, checkboxChecked) => {
            console.log(response);
          });
        }
      },
      {
        label: 'Esci',
        click() {
          app.quit()
        }
      }
    ]
  },
  {
    label: 'Pagina Iniziale',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it");
        }
      }
    ]
  },
  {
    label: 'Iscrizione',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it/iscrizione-landing");
        }
      }
    ]
  },
  {
    label: 'Instagram',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it/instagram");
        }
      }
    ]
  },
  {
    label: 'FaceBook',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("https://facebook.com/ttnovara");
        }
      }
    ]
  },
  {
    label: 'YouTube',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it/youtube");
        }
      }
    ]
  },
  {
    label: 'Diretta Streaming',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it/live");
        }
      }
    ]
  },
  {
    label: 'Galleria',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it/galleria");
        }
      }
    ]
  },
  {
    label: 'Mercatino',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it/mercatino");
        }
      }
    ]
  },
  {
    label: 'Contatti',
    submenu: [
      {
        label: 'Visita', click() {
          mainWindow.loadURL("http://tennistavolonovara.it/contatto");
        }
      }
    ]
  },
])
Menu.setApplicationMenu(menu);

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow)

// Quit when all windows are closed.
app.on('window-all-closed', function () {
  // On macOS it is common for applications and their menu bar
  // to stay active until the user quits explicitly with Cmd + Q
  if (process.platform !== 'darwin') app.quit()
})

app.on('activate', function () {
  // On macOS it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (mainWindow === null) createWindow()
})

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.
